@@ -1,11 +1,9 @@
-use utf8;
-
 package WebService::KvKAPI;
 use Moose;
 
 # ABSTRACT: Query the Dutch Chamber of Commerence (KvK) API
 
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 use namespace::autoclean;
 use OpenAPI::Client;
 use Carp;
@@ -32,16 +30,12 @@ sub search {
     return $results->{data}{items};
 }
 
-sub _search {
-    my ($self, $params) = @_;
-    return $self->api_call('Companies_GetCompaniesBasicV2', $params);
-}
-
 sub search_max {
     my ($self, $max, %params) = @_;
 
     my @items;
     my $answer = $self->_search(\%params);
+    push(@items, @{ $answer->{data}{items} });
 
     while ($answer->{data}{nextLink} && @items < $max) {
         $params{startPage} = $answer->{data}{startPage} + 1;
@@ -56,6 +50,7 @@ sub search_all {
 
     my @items;
     my $answer = $self->_search(\%params);
+    push(@items, @{ $answer->{data}{items} });
 
     while ($answer->{data}{nextLink}) {
         $params{startPage} = $answer->{data}{startPage} + 1;
@@ -68,27 +63,19 @@ sub search_all {
 sub profile {
     my ($self, %params) = @_;
 
-    my $answer = $self->api_call('Companies_GetCompaniesExtendedV2', \%params);
+    my $answer = $self->_profile(\%params);
 
-    if ($answer->{totalItems} == 1) {
-        return $answer->items->[0];
+    if ($answer->{data}{totalItems} == 1) {
+        return $answer->{data}{items}[0];
     }
 
     croak("Unable to find company you where looking for!");
 }
 
-sub _build_open_api_client {
-    my $self = shift;
-
-    my $openapi_url = sprintf('data://%s/kvk_gsasearch_webapi__v1.json', __PACKAGE__);
-    return OpenAPI::Client->new($openapi_url);
-}
-
 sub api_call {
     my ($self, $operation, $query) = @_;
 
-    my $tx
-        = $self->client->$operation({ %$query, user_key => $self->api_key });
+    my $tx = $self->client->$operation({ %$query, user_key => $self->api_key });
 
     if ($tx->error) {
         croak(
@@ -102,6 +89,24 @@ sub api_call {
     return $tx->res->json;
 }
 
+sub _search {
+    my ($self, $params) = @_;
+    return $self->api_call('Companies_GetCompaniesBasicV2', $params);
+}
+
+sub _profile {
+    my ($self, $params) = @_;
+    return $self->api_call('Companies_GetCompaniesExtendedV2', $params);
+}
+
+sub _build_open_api_client {
+    my $self = shift;
+
+    my $openapi_url = sprintf('data://%s/kvk_gsasearch_webapi__v1.json', __PACKAGE__);
+    return OpenAPI::Client->new($openapi_url);
+}
+
+
 __PACKAGE__->meta->make_immutable;
 
 =pod
@@ -114,7 +119,7 @@ WebService::KvKAPI - Query the Dutch Chamber of Commerence (KvK) API
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 AUTHOR
 
@@ -1068,9 +1073,18 @@ __END__
 
 =head1 DESCRIPTION
 
+Query the KvK API via their OpenAPI definition.
+
 =head1 SYNOPSIS
 
-    use WebSerivce
+    use WebService::KvKAPI;
+    my $api = WebService::KvKAPI->new(
+        api_key => 'foobar',
+    );
+
+    $api->search();
+    $api->search_all();
+    $api->search_max();
 
 =head1 ATTRIBUTES
 
@@ -1105,7 +1119,7 @@ Search the KVK, only retrieves the first 10 entries.
 
 =head2 search_all
 
-Seach the KVK, retreives ALL entries. Potentially a very expensive call
+Search the KVK, retreives ALL entries. Potentially a very expensive call
 (money wise). Don't lookup the Albert Heijn KvK number, do more specific
 searches
 
@@ -1116,9 +1130,15 @@ searches
 
 =head2 search_max
 
-Seach the KVK, retreives a maximum of X results up the the nearest 10, eg 15 as a max returns 20 items.
+Search the KVK, retreives a maximum of X results up the the nearest 10, eg 15 as a max returns 20 items.
 
     my $results = $self->search_max(15, kvkNumber => 12345678, ...);
     foreach (@$results) {
         ...;
     }
+
+=head1 SEE ALSO
+
+The KvK also has test endpoints. While they are supported via the direct
+C<api_call> method, you can instantiate a model that works only in
+spoofmode: L<WebService::KvKAPI::Spoof>
